.. _section_install:

Installation
============

ggf is written in pure Python and supports Python version 3.5
and higher.

To install ggf, use one of the following methods
(package dependencies will be installed automatically):
    
* from `PyPI <https://pypi.python.org/pypi/ggf>`_:
    ``pip install ggf``
* from `sources <https://github.com/RI-imaging/ggf>`_:
    ``pip install .`` or 
    ``python setup.py install``

